@@ -15,10 +15,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <sysdeps.h>
+#include <bglibs/sysdeps.h>
 #include <unistd.h>
 
-#include <net/socket.h>
+#include <bglibs/socket.h>
 
 #include "v1client.h"
 #include "protocol.h"
