@@ -15,11 +15,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <sysdeps.h>
+#include <bglibs/sysdeps.h>
 #include <string.h>
-#include <fmt/number.h>
-#include <iobuf/obuf.h>
-#include <msg/msg.h>
+#include <bglibs/fmt.h>
+#include <bglibs/obuf.h>
+#include <bglibs/msg.h>
 #include "v2client.h"
 
 const char program[] = "cvm-testclient";
