@@ -24,13 +24,13 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include <cdb/cdb.h>
-#include <cdb/str.h>
-#include <dict/dict.h>
-#include <dict/load.h>
-#include <iobuf/iobuf.h>
-#include <path/path.h>
-#include <str/str.h>
+#include <bglibs/cdb.h>
+#include <bglibs/cdb.h>
+#include <bglibs/dict.h>
+#include <bglibs/dict.h>
+#include <bglibs/iobuf.h>
+#include <bglibs/path.h>
+#include <bglibs/str.h>
 #include <vmailmgr/vpwentry.h>
 
 #include "module.h"
