@@ -1,5 +1,5 @@
 /* cvm/module_command.c - CVM command module main routine
- * Copyright (C)2006  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2010  Bruce Guenter <bruce@untroubled.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ static int read_input(void)
 static int write_output(void)
 {
   size_t wr;
-  char* ptr;
+  unsigned char* ptr;
   
   for (ptr = cvm_module_outbuffer;
        cvm_module_outbuflen > 0;
