@@ -17,7 +17,7 @@
  */
 #include <stdlib.h>
 
-#include <msg/msg.h>
+#include <bglibs/msg.h>
 
 #include "module.h"
 
